/*
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once
#include <thrift/conformance/if/gen-cpp2/object_types.h>
#include <thrift/lib/cpp2/Object.h>
// TODO: remove this file

namespace apache::thrift::conformance {
using ::apache::thrift::type::asValueStruct;
using ::apache::thrift::type::parseObject;
using ::apache::thrift::type::serializeObject;
} // namespace apache::thrift::conformance
